# cn-Samples.md
## restaurant_search
这附近哪里有吃[food:o](麻辣烫)的地方
想去一家有情调的餐厅
附近有什么好吃的地方吗
找个吃[food:o](拉面)的店

## medical
[disease:o](感冒)了怎么办
我[disease:o](胃痛)，该吃什么药？
一直[disease:o](打喷嚏)怎么办
父母都有[disease:o](高血压)，我会遗传吗

## medical_department
父母都有[disease:o](高血压)，我应该推荐他们去哪家医院好呢
我生病了，不知道去哪里看病
头上烫烫的，感觉[disease:o](发烧)了，该去看哪个诊所哪个科室好呢

## education_experience
比尔盖茨1979年秋天从大学肆业
Rami Eid正在纽约石溪大学学习

## about_date
周四下午三点到五点开会
明天早上跑步
6:30 起床
下下周一开会
7月10日晚上7点左右，六安市公安局裕安分局平桥派出所接到辖区居民戴某报警

